@@ -8,6 +8,7 @@ import textwrap
 from pathlib import Path
 
 import pytest
+from packaging.specifiers import SpecifierSet
 from packaging.version import Version
 
 import scikit_build_core.settings.skbuild_read_settings
@@ -25,9 +26,11 @@ def test_skbuild_settings_default(tmp_path: Path):
     settings = settings_reader.settings
     assert list(settings_reader.unrecognized_options()) == []
 
-    assert settings.ninja.minimum_version == Version("1.5")
+    assert settings.ninja.minimum_version is None
+    assert settings.ninja.version == SpecifierSet(">=1.5")
     assert settings.ninja.make_fallback
-    assert settings.cmake.minimum_version == Version("3.15")
+    assert settings.cmake.minimum_version is None
+    assert settings.cmake.version == SpecifierSet(">=3.15")
     assert settings.cmake.args == []
     assert settings.cmake.define == {}
     assert not settings.cmake.verbose
@@ -49,6 +52,7 @@ def test_skbuild_settings_default(tmp_path: Path):
         "AUTHORS*",
     ]
     assert settings.wheel.exclude == []
+    assert settings.wheel.build_tag == ""
     assert settings.backport.find_python == Version("3.26.1")
     assert settings.strict_config
     assert not settings.experimental
@@ -86,6 +90,7 @@ def test_skbuild_settings_envvar(tmp_path: Path, monkeypatch: pytest.MonkeyPatch
     monkeypatch.setenv("SKBUILD_WHEEL_EXPAND_MACOS_UNIVERSAL_TAGS", "True")
     monkeypatch.setenv("SKBUILD_WHEEL_LICENSE_FILES", "a;b;c")
     monkeypatch.setenv("SKBUILD_WHEEL_EXCLUDE", "b;y;e")
+    monkeypatch.setenv("SKBUILD_WHEEL_BUILD_TAG", "1")
     monkeypatch.setenv("SKBUILD_BACKPORT_FIND_PYTHON", "0")
     monkeypatch.setenv("SKBUILD_STRICT_CONFIG", "0")
     monkeypatch.setenv("SKBUILD_EXPERIMENTAL", "1")
@@ -125,6 +130,7 @@ def test_skbuild_settings_envvar(tmp_path: Path, monkeypatch: pytest.MonkeyPatch
     assert settings.wheel.expand_macos_universal_tags
     assert settings.wheel.license_files == ["a", "b", "c"]
     assert settings.wheel.exclude == ["b", "y", "e"]
+    assert settings.wheel.build_tag == "1"
     assert settings.backport.find_python == Version("0")
     assert not settings.strict_config
     assert settings.experimental
@@ -170,6 +176,7 @@ def test_skbuild_settings_config_settings(
         "wheel.expand-macos-universal-tags": "True",
         "wheel.license-files": ["a", "b", "c"],
         "wheel.exclude": ["b", "y", "e"],
+        "wheel.build-tag": "1foo",
         "backport.find-python": "0",
         "strict-config": "false",
         "experimental": "1",
@@ -208,6 +215,7 @@ def test_skbuild_settings_config_settings(
     assert settings.wheel.expand_macos_universal_tags
     assert settings.wheel.license_files == ["a", "b", "c"]
     assert settings.wheel.exclude == ["b", "y", "e"]
+    assert settings.wheel.build_tag == "1foo"
     assert settings.backport.find_python == Version("0")
     assert not settings.strict_config
     assert settings.experimental
@@ -251,6 +259,7 @@ def test_skbuild_settings_pyproject_toml(
             wheel.expand-macos-universal-tags = true
             wheel.license-files = ["a", "b", "c"]
             wheel.exclude = ["b", "y", "e"]
+            wheel.build-tag = "1_bar"
             backport.find-python = "3.18"
             strict-config = false
             experimental = true
@@ -299,6 +308,7 @@ def test_skbuild_settings_pyproject_toml(
     assert settings.wheel.expand_macos_universal_tags
     assert settings.wheel.license_files == ["a", "b", "c"]
     assert settings.wheel.exclude == ["b", "y", "e"]
+    assert settings.wheel.build_tag == "1_bar"
     assert settings.backport.find_python == Version("3.18")
     assert not settings.strict_config
     assert settings.experimental
@@ -326,8 +336,8 @@ def test_skbuild_settings_pyproject_toml_broken(
         textwrap.dedent(
             """\
             [tool.scikit-build]
-            cmake.minimum-verison = "3.18"
-            ninja.minimum-version = "1.3"
+            cmake.verison = ">=3.18"
+            ninja.version = ">=1.3"
             ninja.make-fallback = false
             logger.level = "ERROR"
             """
@@ -339,7 +349,7 @@ def test_skbuild_settings_pyproject_toml_broken(
 
     settings_reader = SettingsReader.from_file(pyproject_toml, config_settings)
     assert list(settings_reader.unrecognized_options()) == [
-        "tool.scikit-build.cmake.minimum-verison",
+        "tool.scikit-build.cmake.verison",
         "tool.scikit-build.logger",
     ]
 
@@ -352,7 +362,7 @@ def test_skbuild_settings_pyproject_toml_broken(
         ex.split()
         == """\
       ERROR: Unrecognized options in pyproject.toml:
-        tool.scikit-build.cmake.minimum-verison -> Did you mean: tool.scikit-build.cmake.minimum-version, tool.scikit-build.minimum-version, tool.scikit-build.ninja.minimum-version?
+        tool.scikit-build.cmake.verison -> Did you mean: tool.scikit-build.cmake.version, tool.scikit-build.cmake.verbose, tool.scikit-build.cmake.define?
         tool.scikit-build.logger -> Did you mean: tool.scikit-build.logging, tool.scikit-build.generate, tool.scikit-build.wheel?
       """.split()
     )
@@ -363,15 +373,15 @@ def test_skbuild_settings_pyproject_conf_broken(tmp_path, capsys):
     pyproject_toml.write_text("", encoding="utf-8")
 
     config_settings: dict[str, str | list[str]] = {
-        "cmake.minimum-verison": "3.17",
-        "ninja.minimum-version": "1.2",
+        "cmake.verison": ">=3.17",
+        "ninja.version": ">=1.2",
         "ninja.make-fallback": "False",
         "logger.level": "INFO",
     }
 
     settings_reader = SettingsReader.from_file(pyproject_toml, config_settings)
     assert list(settings_reader.unrecognized_options()) == [
-        "cmake.minimum-verison",
+        "cmake.verison",
         "logger",
     ]
 
@@ -385,13 +395,13 @@ def test_skbuild_settings_pyproject_conf_broken(tmp_path, capsys):
         ex.split()
         == """\
       ERROR: Unrecognized options in config-settings:
-        cmake.minimum-verison -> Did you mean: cmake.minimum-version, minimum-version, ninja.minimum-version?
+        cmake.verison -> Did you mean: cmake.version, cmake.verbose, cmake.define?
         logger -> Did you mean: logging?
       """.split()
     )
 
 
-def test_skbuild_settings_min_version_defaults(
+def test_skbuild_settings_min_version_defaults_strip(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ):
     monkeypatch.setattr(
@@ -412,3 +422,86 @@ def test_skbuild_settings_min_version_defaults(
     )
     settings = settings_reader.settings
     assert settings.install.strip
+
+
+def test_skbuild_settings_min_version_versions(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.8.0"
+    )
+
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        "tool.scikit-build.cmake.minimum-version = '3.21'", encoding="utf-8"
+    )
+
+    settings_reader = SettingsReader.from_file(
+        pyproject_toml, {"minimum-version": "0.7"}
+    )
+    settings = settings_reader.settings
+    assert settings.cmake.version == SpecifierSet(">=3.21")
+
+    with pytest.raises(SystemExit):
+        SettingsReader.from_file(pyproject_toml, {"minimum-version": "0.8"})
+
+
+def test_skbuild_settings_version_too_old(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.8.0"
+    )
+
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        "tool.scikit-build.cmake.version = '>=3.21'", encoding="utf-8"
+    )
+
+    SettingsReader.from_file(pyproject_toml, {})
+
+    with pytest.raises(SystemExit):
+        SettingsReader.from_file(pyproject_toml, {"minimum-version": "0.7"})
+
+
+def test_skbuild_settings_pyproject_toml_envvar_defines(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build.cmake.define]
+            a = "1"
+            b = {env = "SIMPLE"}
+            c = {env = "DEFAULT", default="empty"}
+            d = false
+            e = {env = "BOOL", default = false}
+            f = {env = "NOTSET"}
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    config_settings: dict[str, list[str] | str] = {}
+
+    monkeypatch.setenv("SIMPLE", "2")
+    settings_reader = SettingsReader.from_file(pyproject_toml, config_settings)
+    assert settings_reader.settings.cmake.define == {
+        "a": "1",
+        "b": "2",
+        "c": "empty",
+        "d": False,
+        "e": False,
+    }
+
+    monkeypatch.setenv("DEFAULT", "3")
+    monkeypatch.setenv("BOOL", "ON")
+    settings_reader = SettingsReader.from_file(pyproject_toml, config_settings)
+    assert settings_reader.settings.cmake.define == {
+        "a": "1",
+        "b": "2",
+        "c": "3",
+        "d": False,
+        "e": True,
+    }
